==========
brewerwall
==========


.. image:: https://img.shields.io/pypi/v/brewerwall.svg
        :target: https://pypi.python.org/pypi/brewerwall

.. image:: https://img.shields.io/travis/dmofot/brewerwall.svg
        :target: https://travis-ci.org/dmofot/brewerwall

.. image:: https://readthedocs.org/projects/brewerwall/badge/?version=latest
        :target: https://brewerwall.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/dmofot/brewerwall/shield.svg
     :target: https://pyup.io/repos/github/dmofot/brewerwall/
     :alt: Updates



A collection of tools, data and programming resources for all of your beer needs!


* Free software: GNU General Public License v3
* Documentation: https://brewerwall.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `elgertam/cookiecutter-pipenv`_ project template, based on `audreyr/cookiecutter-pypackage`_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`elgertam/cookiecutter-pipenv`: https://github.com/elgertam/cookiecutter-pipenv
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
